if [ -f /bin/bash ]; then
  ( cd bin ; cp bash bash.old )
  ( cd bin ; mv bash.new bash )
fi
( cd bin ; rm -rf sh )
( cd bin ; ln -sf bash sh )
( cd usr/bin ; rm -rf bash )
( cd usr/bin ; ln -sf ../bin/bash bash )
